import java.util.function.Consumer;
import java.util.function.Supplier;
import java.util.function.Function;
import java.util.function.Predicate;

public class FunctionalInterfacesExample {
    public static void main(String[] args) {
        // 1. Consumer - Prints a message
        // The `printMessage` consumer takes a string and prints it with a prefix.
        // We use `.accept()` to execute the operation.
        Consumer<String> printMessage = message -> System.out.println("Message: " + message);
        printMessage.accept("Hello, world!");

        // 2. Supplier - Supplies a random number
        // The `randomNumberSupplier` is a supplier that generates a random number.
        // We use `.get()` to retrieve the value.
        Supplier<Double> randomNumberSupplier = () -> Math.random();
        System.out.println("Random number: " + randomNumberSupplier.get());

        // 3. Function - Transforms an integer to a string
        // The `intToString` function takes an integer and returns a string that describes the number.
        // We use `.apply()` to perform the transformation.
        Function<Integer, String> intToString = number -> "The number is: " + number;
        System.out.println(intToString.apply(42));

        // 4. Predicate - Checks if a number is even
        // The `isEven` predicate checks if a number is even.
        // We use `.test()` to evaluate the condition and return a boolean result.
        Predicate<Integer> isEven = number -> number % 2 == 0;
        System.out.println("Is 4 even? " + isEven.test(4));  // true
        System.out.println("Is 7 even? " + isEven.test(7));  // false
    }
}
