// Functional interface with no parameters
@FunctionalInterface
interface NoParameter {
    void greet();
}

// Functional interface with one parameter
@FunctionalInterface
interface OneParameter {
    int square(int x);
}

// Functional interface with multiple parameters
@FunctionalInterface
interface TwoParameters {
    int add(int a, int b);
}

// Functional interface with a block body (multiple statements)
@FunctionalInterface
interface BlockBody {
    void displayMessage(String message);
}

// Functional interface with an explicit return statement
@FunctionalInterface
interface WithReturn {
    String greet(String name);
}

public class LambdaVariations {
    public static void main(String[] args) {
        // Zero parameters - No arguments, just a simple lambda
        NoParameter sayHello = () -> System.out.println("Hello, World!");
        sayHello.greet();

        // One parameter - Parentheses optional when there's a single parameter
        OneParameter square = x -> x * x;  // Equivalent to (x) -> { return x * x; }
        System.out.println("Square of 5: " + square.square(5));

        // Multiple parameters - Requires parentheses
        TwoParameters sum = (a, b) -> a + b;
        System.out.println("Sum of 3 and 7: " + sum.add(3, 7));

        // Block body - Using multiple statements in the lambda
        BlockBody messagePrinter = (message) -> {
            System.out.println("Processing message...");
            System.out.println("Message: " + message);
        };
        messagePrinter.displayMessage("Lambda expressions are powerful!");

        // Using a return statement explicitly
        WithReturn greeter = (name) -> {
            return "Hello, " + name + "!";
        };
        System.out.println(greeter.greet("Alice"));
    }
}

